﻿using System;
using System.IO;
using System.Windows.Forms;

namespace FilePropertyModify
{
    /// <summary>
    /// 文件属性修改器
    /// </summary>
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// 浏览文件
        /// </summary>
        private void SelectFileButton_Click(object sender, EventArgs e)
        {
            if (this.openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                this.FileListBox.Items.AddRange(this.openFileDialog1.FileNames);
            }
        }

        /// <summary>
        /// 绑定文件属性
        /// </summary>
        private void BindFileProperty()
        {
            if (File.Exists(this.FileListBox.Text))
            {
                this.CreationTimeTimePicker.Text = File.GetCreationTime(this.FileListBox.Text).ToString();
                this.LastAccessTimePicker.Text = File.GetLastAccessTime(this.FileListBox.Text).ToString();
                this.LastWriteTimeTimePicker.Text = File.GetLastWriteTime(this.FileListBox.Text).ToString();
                string FileType = File.GetAttributes(this.FileListBox.Text).ToString();
                this.SystemCheckBox.Checked = (FileType.LastIndexOf("System") != -1);
                this.HiddenCheckBox.Checked = (FileType.LastIndexOf("Hidden") != -1);
                this.ReadOnlyCheckBox.Checked = (FileType.LastIndexOf("ReadOnly") != -1);
                //下面这两种感觉没啥用就不显示了
                //FileType.LastIndexOf("Archive") != -1 是否归档文件
                //FileType.LastIndexOf("Temporary") != -1 是否临时文件
            }
        }

        /// <summary>
        /// 设置文件属性
        /// </summary>
        private void SetPropertyButton_Click(object sender, EventArgs e)
        {
            int Test = 3000;
            foreach (string file in this.FileListBox.Items)
            {
                try
                {
                    if (File.Exists(file))
                    {
                        File.SetAttributes(file, System.IO.FileAttributes.Normal);
                        if (this.ReadOnlyCheckBox.Checked == true)
                        {
                            File.SetAttributes(file, System.IO.FileAttributes.ReadOnly);
                        }
                        //获取文件属性
                        var FileAttributes = File.GetAttributes(file);
                        if (this.SystemCheckBox.Checked == true)
                        {
                            File.SetAttributes(file, FileAttributes | FileAttributes.System);
                        }
                        //再次获取文件属性
                        FileAttributes = File.GetAttributes(file);
                        if (this.HiddenCheckBox.Checked == true)
                        {
                            File.SetAttributes(file, FileAttributes | FileAttributes.Hidden);
                        }
                        File.SetCreationTime(file, this.CreationTimeTimePicker.Value);
                        File.SetLastAccessTime(file, this.LastAccessTimePicker.Value);
                        File.SetLastWriteTime(file, this.LastWriteTimeTimePicker.Value);
                    }
                }
                catch (Exception)
                {
                    //感觉没必要报错就这样吧
                }
            }
        }

        private void MainForm_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop))
            {
                e.Effect = DragDropEffects.All;
            }
            else
            {
                e.Effect = DragDropEffects.None;
            }
        }

        private void MainForm_DragDrop(object sender, DragEventArgs e)
        {
            var FileNames = ((Array)e.Data.GetData(DataFormats.FileDrop));
            foreach (string item in FileNames)
            {
                if (File.Exists(item))
                {
                    this.FileListBox.Items.Add(item);
                }
            }
            foreach (string item in FileNames)
            {
                if (Directory.Exists(item))
                {
                    this.FileListBox.Items.AddRange(Directory.GetFiles(item));
                }
            }
        }

        private void RandomButton_Click(object sender, EventArgs e)
        {
            this.TopMost = false;
            var RandomForm = new RandomTimeForm();
            RandomForm.ShowDialog();
            var CurrRandomTime= RandomForm.RandomTime;
            this.CreationTimeTimePicker.Value = CurrRandomTime;
            this.LastWriteTimeTimePicker.Value = CurrRandomTime.AddSeconds(new Random().Next(100, 600)); 
            this.LastAccessTimePicker.Value = this.LastWriteTimeTimePicker.Value.AddSeconds(new Random().Next(100, 600)); ;
            this.TopMost = true;
        }

        private void ClearButton_Click(object sender, EventArgs e)
        {
            FileListBox.Items.Clear();
        }

        private void FileListBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            BindFileProperty();
        }

    }
}
